@@ -3,13 +3,12 @@ BEGIN {
   $Bio::BLAST::Database::AUTHORITY = 'cpan:RBUELS';
 }
 BEGIN {
-  $Bio::BLAST::Database::VERSION = '0.2';
+  $Bio::BLAST::Database::VERSION = '0.3';
 }
 # ABSTRACT: work with formatted BLAST databases
 
 use strict;
 use warnings;
-use namespace::autoclean;
 
 use POSIX;
 
@@ -32,6 +31,8 @@ use List::MoreUtils qw/ all any /;
 
 use Bio::BLAST::Database::Seq;
 
+use namespace::clean;
+
 
 use base qw/ Class::Accessor::Fast /;
 
@@ -64,10 +65,6 @@ sub open {
         croak $perm_error if $perm_error;
     }
 
-    if($self->write and my @files = $self->list_files ) {
-        warn (map "$_\n", "already present:", map " - $_", @files);
-    }
-
     # set some of our attrs from the existing files
     $self->_read_fastacmd_info;
 
